@@ -16,6 +16,21 @@ def get_args_list(args_str):
     pass
 
 
+def check_for_numeric_type(string: str):
+    num = float(string)
+    if num == int(num):
+        num = int(num)
+    return num
+
+
+def is_numeric(string: str):
+    try:
+        float(string)
+        return True
+    except ValueError:
+        return False
+
+
 def get_args_st(doc, n):
     start = doc.find("(")
     end = doc.find(")")
@@ -26,6 +41,11 @@ def get_args_st(doc, n):
 
 if __name__ == "__main__":
     # doc = "fds(dasd,dasd dasd) dasd sdaftqwe "
-    doc = np.add.__doc__
-    args = get_args_st(doc, 2)
-    print(args)
+    # doc = np.add.__doc__
+    # args = get_args_st(doc, 2)
+    # print(args)
+    is_numeric("2")
+    is_numeric("2a")
+    is_numeric("-2")
+    is_numeric("-2.2")
+    is_numeric("23.")
