@@ -1,11 +1,25 @@
 import numpy as np
 # from numpy.random import normal
+import random
 
 
 def add(params0, params1):
     return params0 + params1
 
 
+def add_noise(x):
+    return x + np.random.normal()
+
+
+def printing(num, phra):
+    aa = phra * num
+    return aa
+
+
+def get_bool():
+    return random.choice([False, True])
+
+
 def square_plus_constant(z, constant):
     # print(globals())
     # print(globals()["testValue"])
